@@ -4,8 +4,11 @@ use Pcore -class, -const, -export => { CONST => [qw[$WHOIS_FOUND $WHOIS_NOT_FOUN
 
 extends qw[Pcore::API::Response];
 
-has server => ( is => 'ro' );
-has content => ( is => 'ro', isa => ScalarRef );
+has query => ( is => 'ro', isa => Str, required => 1 );
+
+has server    => ( is => 'ro' );
+has content   => ( is => 'ro', isa => ScalarRef );
+has is_cached => ( is => 'ro', isa => Bool, default => 0 );
 
 const our $WHOIS_FOUND         => 200;    # NOT available for registration
 const our $WHOIS_NOT_FOUND     => 201;    # available for registration
